+++
title = "Expiry date set using DEADLINE"
expiryDate = 2999-01-01T00:00:00+00:00
tags = ["dates", "expirydate", "deadline"]
draft = false
+++

If a subtree has the `DEADLINE` [Special Property](https://orgmode.org/manual/Special-properties.html) set, set the
`expirydate` front-matter to the deadline date.

By default, `C-c C-d` in Org adds the `DEADLINE` property to the
current subtree.
